@@ -645,7 +645,8 @@ ProjectWindow::ProjectWindow(wxWindow * parent, wxWindowID id,
 
    mContainerWindow->Initialize(mTrackListWindow);
 
-   auto effectsPanel = safenew ThemedWindowWrapper<RealtimeEffectPanel>(mProject, mContainerWindow, wxID_ANY);
+   auto effectsPanel = safenew ThemedWindowWrapper<RealtimeEffectPanel>(
+      project, mContainerWindow, wxID_ANY);
    effectsPanel->SetName(_("Realtime effects"));
    effectsPanel->SetBackgroundColorIndex(clrMedium);
    effectsPanel->Hide();//initially hidden
@@ -703,9 +704,10 @@ ProjectWindow::ProjectWindow(wxWindow * parent, wxWindowID id,
       .Subscribe([this](const TrackFocusChangeMessage& msg) {
          if(mEffectsWindow->IsShown())
          {
-            auto& project = GetProject();
-            auto& trackFocus = TrackFocus::Get(project);
-            ShowEffectsPanel(trackFocus.Get(), false);
+            if (auto project = FindProject()) {
+               auto& trackFocus = TrackFocus::Get(*project);
+               ShowEffectsPanel(trackFocus.Get(), false);
+            }
          }
       });
 
@@ -739,7 +741,6 @@ END_EVENT_TABLE()
 
 void ProjectWindow::ApplyUpdatedTheme()
 {
-   auto &project = mProject;
    SetBackgroundColour(theTheme.Colour( clrMedium ));
    ClearBackground();// For wxGTK.
 }
@@ -754,7 +755,11 @@ void ProjectWindow::RedrawProject(const bool bForceWaveTracks /*= false*/)
    if (pThis->IsBeingDeleted())
       return;
 
-   auto &project = pThis->mProject ;
+   auto pProject = pThis->FindProject();
+   if (!pProject)
+      return;
+
+   auto &project = *pProject;
    auto &tracks = TrackList::Get( project );
    auto &trackPanel = GetProjectPanel( project );
    pThis->FixScrollbars();
@@ -771,9 +776,13 @@ void ProjectWindow::RedrawProject(const bool bForceWaveTracks /*= false*/)
 
 void ProjectWindow::OnThemeChange(ThemeChangeMessage message)
 {
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
+
    if (message.appearance)
       return;
-   auto &project = mProject;
    this->ApplyUpdatedTheme();
    auto &toolManager = ToolManager::Get( project );
    for( int ii = 0; ii < ToolBarCount; ++ii )
@@ -823,8 +832,12 @@ const int sbarHjump = 30;       //STM: This is how far the thumb jumps when the
 // Make sure selection edge is in view
 void ProjectWindow::ScrollIntoView(double pos)
 {
-   auto &trackPanel = GetProjectPanel( mProject );
-   auto &viewInfo = ViewInfo::Get( mProject );
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
+   auto &trackPanel = GetProjectPanel( project );
+   auto &viewInfo = ViewInfo::Get( project );
    auto w = viewInfo.GetTracksUsableWidth();
 
    int pixel = viewInfo.TimeToPosition(pos);
@@ -838,7 +851,11 @@ void ProjectWindow::ScrollIntoView(double pos)
 
 void ProjectWindow::ScrollIntoView(int x)
 {
-   auto &viewInfo = ViewInfo::Get( mProject );
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
+   auto &viewInfo = ViewInfo::Get( project );
    ScrollIntoView(viewInfo.PositionToTime(x, viewInfo.GetLeftOffset()));
 }
 
@@ -848,7 +865,10 @@ void ProjectWindow::ScrollIntoView(int x)
 ///
 void ProjectWindow::OnScrollLeft()
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    wxInt64 pos = mHsbar->GetThumbPosition();
    // move at least one scroll increment
@@ -871,7 +891,10 @@ void ProjectWindow::OnScrollLeft()
 
 void ProjectWindow::OnScrollRight()
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    wxInt64 pos = mHsbar->GetThumbPosition();
    // move at least one scroll increment
@@ -896,7 +919,10 @@ void ProjectWindow::OnScrollRight()
 ///
 void ProjectWindow::OnScrollLeftButton(wxScrollEvent & /*event*/)
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    wxInt64 pos = mHsbar->GetThumbPosition();
    // move at least one scroll increment
@@ -917,7 +943,10 @@ void ProjectWindow::OnScrollLeftButton(wxScrollEvent & /*event*/)
 ///
 void ProjectWindow::OnScrollRightButton(wxScrollEvent & /*event*/)
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    wxInt64 pos = mHsbar->GetThumbPosition();
    // move at least one scroll increment
@@ -939,7 +968,10 @@ void ProjectWindow::OnScrollRightButton(wxScrollEvent & /*event*/)
 
 bool ProjectWindow::MayScrollBeyondZero() const
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return false;
+   auto &project = *pProject;
    auto &scrubber = Scrubber::Get( project );
    auto &viewInfo = ViewInfo::Get( project );
    if (viewInfo.bScrollBeyondZero)
@@ -960,7 +992,10 @@ bool ProjectWindow::MayScrollBeyondZero() const
 
 double ProjectWindow::ScrollingLowerBoundTime() const
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return 0;
+   auto &project = *pProject;
    auto &tracks = TrackList::Get( project );
    auto &viewInfo = ViewInfo::Get( project );
    if (!MayScrollBeyondZero())
@@ -973,7 +1008,10 @@ double ProjectWindow::ScrollingLowerBoundTime() const
 // That's why ViewInfo::TimeRangeToPixelWidth was defined, with some regret.
 double ProjectWindow::PixelWidthBeforeTime(double scrollto) const
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return 0;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    const double lowerBound = ScrollingLowerBoundTime();
    return
@@ -983,7 +1021,10 @@ double ProjectWindow::PixelWidthBeforeTime(double scrollto) const
 
 void ProjectWindow::SetHorizontalThumb(double scrollto)
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    const auto unscaled = PixelWidthBeforeTime(scrollto);
    const int max = mHsbar->GetRange() - mHsbar->GetThumbSize();
@@ -1046,7 +1087,10 @@ bool ProjectWindow::TP_ScrollUpDown(int delta)
 
 void ProjectWindow::FixScrollbars()
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &tracks = TrackList::Get( project );
    auto &trackPanel = GetProjectPanel( project );
    auto &viewInfo = ViewInfo::Get( project );
@@ -1202,7 +1246,10 @@ void ProjectWindow::FixScrollbars()
 
 void ProjectWindow::UpdateLayout()
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &trackPanel = GetProjectPanel( project );
    auto &toolManager = ToolManager::Get( project );
 
@@ -1296,6 +1343,10 @@ void ProjectWindow::Reset()
 
 void ProjectWindow::UpdateStatusWidths()
 {
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    enum { nWidths = nStatusBarFields + 1 };
    int widths[ nWidths ]{ 0 };
    widths[ rateStatusBarField ] = 150;
@@ -1308,7 +1359,7 @@ void ProjectWindow::UpdateStatusWidths()
       int &width = widths[ ii ];
       for ( const auto &function : functions ) {
          auto results =
-            function( mProject, static_cast< StatusBarField >( ii ) );
+            function( project, static_cast< StatusBarField >( ii ) );
          for ( const auto &string : results.first ) {
             int w;
             statusBar->GetTextExtent(string.Translation(), &w, nullptr);
@@ -1483,7 +1534,10 @@ void ProjectWindow::OnUndoReset()
 
 void ProjectWindow::OnScroll(wxScrollEvent & WXUNUSED(event))
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    const wxInt64 offset = PixelWidthBeforeTime(0.0);
    viewInfo.sbarH =
@@ -1501,7 +1555,10 @@ void ProjectWindow::OnScroll(wxScrollEvent & WXUNUSED(event))
 
 void ProjectWindow::DoScroll()
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &trackPanel = GetProjectPanel( project );
    auto &viewInfo = ViewInfo::Get( project );
    const double lowerBound = ScrollingLowerBoundTime();
@@ -1547,9 +1604,12 @@ void ProjectWindow::OnMenu(wxCommandEvent & event)
       return;
    }
 #endif
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &commandManager = CommandManager::Get( project );
-   bool handled = commandManager.HandleMenuID( GetProject(),
+   bool handled = commandManager.HandleMenuID( project,
       event.GetId(), MenuManager::Get( project ).GetUpdateFlags(),
       false);
 
@@ -1563,7 +1623,10 @@ void ProjectWindow::OnMenu(wxCommandEvent & event)
 
 void ProjectWindow::OnUpdateUI(wxUpdateUIEvent & WXUNUSED(event))
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    MenuManager::Get( project ).UpdateMenus();
 }
 
@@ -1575,7 +1638,10 @@ void ProjectWindow::OnActivate(wxActivateEvent & event)
       return;
    }
 
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
 
    mActive = event.GetActive();
 
@@ -1606,14 +1672,20 @@ bool ProjectWindow::IsActive()
 
 void ProjectWindow::OnMouseEvent(wxMouseEvent & event)
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    if (event.ButtonDown())
       SetActiveProject( &project );
 }
 
 void ProjectWindow::ZoomAfterImport(Track *pTrack)
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &tracks = TrackList::Get( project );
    auto &trackPanel = GetProjectPanel( project );
 
@@ -1633,7 +1705,10 @@ void ProjectWindow::ZoomAfterImport(Track *pTrack)
 // Utility function called by other zoom methods
 void ProjectWindow::Zoom(double level)
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    viewInfo.SetZoom(level);
    FixScrollbars();
@@ -1652,7 +1727,10 @@ void ProjectWindow::Zoom(double level)
 // Utility function called by other zoom methods
 void ProjectWindow::ZoomBy(double multiplier)
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    viewInfo.ZoomBy(multiplier);
    FixScrollbars();
@@ -1668,7 +1746,10 @@ void ProjectWindow::ZoomBy(double multiplier)
 ///////////////////////////////////////////////////////////////////
 void ProjectWindow::Rewind(bool shift)
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    viewInfo.selectedRegion.setT0(0, false);
    if (!shift)
@@ -1688,7 +1769,10 @@ void ProjectWindow::Rewind(bool shift)
 ///////////////////////////////////////////////////////////////////
 void ProjectWindow::SkipEnd(bool shift)
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &tracks = TrackList::Get( project );
    auto &viewInfo = ViewInfo::Get( project );
    double len = tracks.GetEndTime();
@@ -1782,7 +1866,10 @@ void ProjectWindow::PlaybackScroller::OnTimer()
 
 void ProjectWindow::ZoomInByFactor( double ZoomFactor )
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
 
    auto gAudioIO = AudioIO::Get();
@@ -1862,7 +1949,10 @@ void ProjectWindow::ZoomInByFactor( double ZoomFactor )
 
 void ProjectWindow::ZoomOutByFactor( double ZoomFactor )
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
 
    //Zoom() may change these, so record original values:
@@ -1879,7 +1969,10 @@ void ProjectWindow::ZoomOutByFactor( double ZoomFactor )
 
 double ProjectWindow::GetZoomOfToFit() const
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return 1.0;
+   auto &project = *pProject;
    auto &tracks = TrackList::Get( project );
    auto &viewInfo = ViewInfo::Get( project );
 
@@ -1899,7 +1992,10 @@ double ProjectWindow::GetZoomOfToFit() const
 
 void ProjectWindow::DoZoomFit()
 {
-   auto &project = mProject;
+   auto pProject = FindProject();
+   if (!pProject)
+      return;
+   auto &project = *pProject;
    auto &viewInfo = ViewInfo::Get( project );
    auto &tracks = TrackList::Get( project );
    auto &window = *this;
